pub enum DeviceState {
NotAttached,
Attached,
Powered,
Default,
Address,
Configured,
Suspended,
// some variants omitted
}Expand description
Device States mirrors the descriptions in Section 9.1 of the USB 2.0 spec
Variants
NotAttached
Attached
Powered
Default
3 is reserved for RECONNECTING, which is an unused legacy value for wireless USB 4 is reserved for UNAUTHENTICATED, which is an unused legacy value for wireless USB
Address
Configured
Suspended
Implementations
Sourceimpl DeviceState
impl DeviceState
pub fn from_primitive(prim: u32) -> Option<Self>
pub fn from_primitive_allow_unknown(prim: u32) -> Self
pub fn unknown() -> Self
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool